//|========================================================
//| Simplest Caption Example
//| Mike G7GTN - April 2020
//|========================================================
//| A simple OSD Generator.
//| Switch on I/O D5 will switch between pre-set
//| captions.
//|
//| Required libraries:-
//|
//|  https://github.com/nootropicdesign/arduino-tvout-ve
//|  https://github.com/mathertel/OneButton
//| 
//|
//| Button Usage:-
//|
//|        Single click  = Caption One
//|        Double click  = Caption Two
//|        Long Press    = Caption Off
//| 
//|========================================================

#include <TVout.h>
#include <fontALL.h>
#include "OneButton.h"

#define W 100                // Resolution
#define H 30

// Setup a new OneButton on pin D5.  
OneButton button(5, true);

TVout tv;

// Hardware
void setup()  
{
  tv.begin(PAL, W, H);
  initOverlay();
  tv.select_font(font8x8);
  tv.fill(0);
  button.attachClick(singleclick);   
  button.attachDoubleClick(doubleclick);
  button.attachLongPressStop(longclick); 
}

// Initialize ATMega registers for video overlay capability.
// Must be called after tv.begin().
void initOverlay() 
{
  TCCR1A = 0;
  // Enable timer1.  ICES0 is set to 0 for falling edge detection on input capture pin.
  TCCR1B = _BV(CS10);

  // Enable input capture interrupt
  TIMSK1 |= _BV(ICIE1);

  // Enable external interrupt INT0 on pin 2 with falling edge.
  EIMSK = _BV(INT0);
  EICRA = _BV(ISC01);
}

// Required to reset the scan line when the vertical sync occurs
ISR(INT0_vect) 
{
  display.scanLine = 0;
}

// Caption
void caption()
{
  tv.clear_screen();
  tv.print(2,1,"G7GTN");
  tv.print(2,9,"AMATEUR");
  tv.print(2,17,"TELEVISION");
}

void captionTwo()
{
  tv.clear_screen();
  tv.print(2,1,"CAPTION");
  tv.print(26,9,"2");  
}

// Clear screen
void clearScreen()
{
  tv.clear_screen();
}

void loop()
{
  button.tick();
  delay(30);  
}

// First Caption
void singleclick()
{                                                               
 caption();
}

// Second Caption
void doubleclick() 
{
  captionTwo();
}

// Clear Captions
void longclick()
{                                   
  clearScreen();
}
  
